##  Benefits for Different Stakeholders
For CIOs:
  * Understand the target architecture and its benefits for business and IT.
  * Gain transparency on the transformation approach and important milestones.
  * Understand what decisions need to be taken and who needs to be involved at the C-level.
  * Have a view of the target architecture, track progress toward the to-be state, and have transparency of milestones and if your transformation is on track.
  * Maintain a view of the target architecture, track progress towards the to-be state, and ensure the transparency of milestones and transformation progress.


For Enterprise Architects:
  * Efficient data collection using SAP LeanIX surveys for a comprehensive understanding of the as-is landscape.
  * Leverage SAP LeanIX’s "Transformations" capability to visualize and compare scenarios of your to-be state.
  * Understand and share to-be application landscape and transformation roadmaps with stakeholders for better planning and coordination, leveraging SAP LeanIX reports.
  * Establish a single source of truth for all transformation-related activities instead of being dependent on unreliable and outdated spreadsheets.
  * Efficiently extract relevant data that aid stakeholders in making prompt decisions, highlighting impacts and risks.
  * After your transformation, understand where there is still technical debt and custom implementations in your landscape.


For Program and Project Managers:
  * Improved understanding of as-is and to-be states.
  * Transparency around important technological risks and corresponding milestones.
  * More effective preparation of decisions by documenting scenarios.
  * Reduction of typical risks associated with ERP transformation (for example, missing or incompatible interfaces).
